@@ -5,6 +5,7 @@ from builtins import str
 from builtins import object
 import logging
 import os
+import json
 
 from google.cloud import pubsub_v1
 
@@ -12,21 +13,17 @@ LOGGER = logging.getLogger(__name__)
 
 
 class BaseConsumer(object):
+    TOPIC_ID = None
     subscription_name = None
 
-    def __init__(self, topic_id):
-        if self is BaseConsumer:
-            raise Exception(
-                "Can't directly use the BaseConsumer class. Please extend it.")
-
-        subscriber_project_id = os.getenv('PUBSUB_PROJECT_ID'),
+    def __init__(self):
         self.subscription_name = 'projects/{project_id}/subscriptions/{sub}'.format(
             project_id=os.getenv('PUBSUB_PROJECT_ID'),
-            sub=topic_id + '-' + subscriber_project_id
+            sub=self.topic_id
         )
         self.instance = pubsub_v1.SubscriberClient()
 
-    def on_message(self, message):
+    def on_message(self, message_id, data, attributes, publish_time):
         pass
 
     def run(self):
@@ -35,7 +32,8 @@ class BaseConsumer(object):
                         message.message_id, message.common_project_path, message.data)
 
             try:
-                self.on_message(message)
+                self.on_message(message.message_id, json.loads(message.data),
+                                message.attributes, message.publish_time)
                 message.ack()
             except Exception as e:
                 LOGGER.warning(
